@@ -1,6 +1,6 @@
 package NetHack::Item::Food;
 {
-  $NetHack::Item::Food::VERSION = '0.18';
+  $NetHack::Item::Food::VERSION = '0.19';
 }
 use Moose;
 extends 'NetHack::Item';
@@ -20,6 +20,12 @@ has is_laid_by_you => (
     default => 0,
 );
 
+has is_custom_fruit => (
+    is      => 'rw',
+    isa     => 'Bool',
+    default => 0,
+);
+
 with 'NetHack::Item::Role::IncorporatesStats' => {
     attribute => 'is_partly_eaten',
     stat      => 'eaten',
@@ -35,6 +41,13 @@ sub nutrition_per_weight {
     return $self->nutrition / $self->weight;
 }
 
+after incorporate_stats => sub {
+    my $self = shift;
+    my $stats = shift;
+
+    $self->is_custom_fruit($stats->{is_custom_fruit});
+};
+
 __PACKAGE__->meta->install_spoilers(qw/nutrition time vegan vegetarian/);
 
 __PACKAGE__->meta->make_immutable;
